Package 'flowers'

Title: Flower Plots
Description: Flowers provides functions to generate flower plot graphics.
Authors: Jim Regetz [aut], Darren Hardy [aut], Ben Best [aut] (ORCID: <https://orcid.org/0000-0002-2686-0784>), Casey O'Hara [aut] (ORCID: <https://orcid.org/0000-0003-2968-7005>), Julia Lowndes [aut] (ORCID: <https://orcid.org/0000-0003-1682-3872>), Melanie Frazier [aut], Jamie Afflerbach [aut], Juliette Verstaen [aut], Matthew B. Jones [aut, cre] (ORCID: <https://orcid.org/0000-0003-0077-4738>)
Maintainer: Matthew B. Jones <[email protected]>
License: GPL-3
Version: 0.2.0
Built: 2026-05-14 05:13:32 UTC
Source: https://github.com/NCEAS/flowers

Help Index


Ocean Health Index scores.

Description

A dataset containing the calculated scores for Ocean Health Indices.

Usage

ohi

Format

A data frame with 53940 rows and 10 variables:

goal

OHI goal code

score

OHI score for this goal

order

relative order of the petals

weight

relative weight of the petal, from 0 to 1

category

name of the parent category for grouped petals

label

name for the label to be displayed on each petal

...

http://ohi-science.org/


Flower plot

Description

Flower plot

Usage

plot_flower(.Data, title = NA, legend_include = TRUE, colors = NA,
  fixed_colors = FALSE, filename = NA)

Arguments

.Data

data frame containing scores to be plotted. Column names should include "score", "weight", "category", and "label"

title

optional title for the plot

legend_include

logical, whether to include a plot legend, defaults to TRUE

colors

an optional color palette to be used for the petal colors

fixed_colors

if TRUE, then use a discrete fixed color palette for coloring petals based on petal categories; defaults to FALSE,

filename

if not NA, save the figure using this filename (relative or absolute)

Value

ggplot object of the flowerplot

Examples

data(ohi)
plot_flower(ohi, "OHI Example")